import loading from "@/components/Provider/Loading";
import Modal from "@/components/Provider/Modal";
import { ListController } from "@/controllers/ListController";
import { request } from "@/modules/objects";
import router from "@/views/admin/router";
import { message } from "ant-design-vue";
import { defineStore } from "pinia";
import { https } from "./https";

export const useAuth = defineStore("auth", {
  state: () => ({
    userListController: new ListController(request),
    userInfo: {} as any,
  }),
  getters: {},
  actions: {
    async initAuth() {
      this.userListController.setCrudPrefix("/usercenter/user");
      this.queryUser();
    },
    async queryUser() {
      const res = await https.queryUserInfo();
      if (res.errorNo == 200) {
        this.$state.userInfo = res.result.user;
      } else {
        localStorage.removeItem("token");
        router.push("/login");
      }
    },

    async passwordLogin(data: any) {
      const res = await https.passwordLogin(data);
      if (res.errorNo == 200) {
        this.$state.userInfo = res.result.user;
        localStorage.setItem("token", res.result.token);
        router.push("/");
      } else {
        message.error(res.errorDesc);
      }
    },
    logout() {
      localStorage.removeItem("token");
      router.push("/login");
    },

    async addOrUpdateUser(item: any) {
      loading.show("保存中");
      let res = {} as any;
      if (item._id) {
        res = await this.userListController.saveItem(item);
      } else {
        res = await this.userListController.addItem(item);
      }
      loading.hidden();
      if (res.errorNo != 200) {
        message.success(res.errorDesc);
        return;
      }
      message.success("保存成功");
    },

    async deleteUser(item: any) {
      const ok = await Modal.confirm({
        title: "删除确认",
        content: `删除后数据无法恢复，确认删除：${item?.name}？`,
        type: "danger",
      });
      if (ok) {
        loading.show("删除中");
        await this.userListController.deleteItem(item._id);
        loading.hidden();
        message.success("删除成功");
      }
    },
  },
});
