import Modal from "@/components/Provider/Modal";
import { Button, Form, Input } from "ant-design-vue";
import { defineComponent, reactive } from "vue";
import { any } from "vue-types";

const layout = {
  labelCol: { span: 5 },
  wrapperCol: { span: 18 },
};

export default defineComponent({
  props: {
    data: any(),
  },
  setup(props) {
    const modal = Modal.use();

    const formState: { [name: string]: any } = reactive({
      loginName: "",
      name: "",
      phone: "",
      password: "",
      ...props.data,
    });

    const rules = reactive({
      loginName: [
        { required: true, message: "登录名不能为空", trigger: "change" },
      ],
      name: [{ required: true, message: "姓名不能为空", trigger: "change" }],
      phone: [
        { required: false, message: "手机号不能为空", trigger: "change" },
      ],
      password: [
        {
          required: props.data._id ? false : true,
          message: "密码不能为空",
          trigger: "change",
        },
        {
          min: 6,
          max: 18,
          message: "密码长度为6~18位字符",
          trigger: "change",
        },
      ],
    });

    const { validate, validateInfos } = Form.useForm(formState, rules);

    function submit() {
      validate().then(async () => {
        modal.submit(formState);
      });
    }

    return () => {
      return (
        <Form {...layout} onSubmit={submit}>
          <Form.Item {...validateInfos.loginName} label="登录名">
            <Input
              disabled={props.data?._id ? true : false}
              placeholder="请输入登录名"
              v-model={[formState.loginName, "value"]}
              maxlength={10}
            />
          </Form.Item>
          <Form.Item {...validateInfos.name} label="姓名">
            <Input
              placeholder={"请输入姓名"}
              v-model={[formState.name, "value"]}
              maxlength={10}
            />
          </Form.Item>
          <Form.Item {...validateInfos.phone} label="手机号">
            <Input
              placeholder="请输入手机号"
              v-model={[formState.phone, "value"]}
              maxlength={11}
            />
          </Form.Item>
          <Form.Item {...validateInfos.password} label="密码">
            <Input.Password
              placeholder="请输入密码"
              v-model={[formState.password, "value"]}
              maxlength={10}
            />
          </Form.Item>
          <Form.Item style={{ marginBottom: 0 }} wrapperCol={{ span: 24 }}>
            <Button type="primary" htmlType="submit" block>
              保存
            </Button>
          </Form.Item>
        </Form>
      );
    };
  },
});
