import { CloseOutlined, SearchOutlined } from "@ant-design/icons-vue";
import { css, cx } from "@linaria/core";
import { Input } from "ant-design-vue";
import { defineComponent, reactive, ref } from "vue";
import { useRouter } from "vue-router";

export default defineComponent({
  setup() {
    const router = useRouter();

    const searchInputRef = ref();

    const state = reactive({
      visible: false,
      showSearch: false,
      showSearchOverlay: false,
    });

    return () => (
      <>
        <SearchOutlined
          class="text-24px !text-primary"
          onClick={() => {
            state.showSearchOverlay = true;
            searchInputRef.value.focus();
          }}
        />
        <div
          class={cx(
            state.showSearchOverlay ? "h-1/1" : "h-0",
            "fixed mobile_search bg-primary bg-opacity-95 w-1/1 left-0 top-0 z-20 transition-all ease-in-out overflow-hidden"
          )}
        >
          <div class="flex justify-end">
            <CloseOutlined
              onClick={() => (state.showSearchOverlay = false)}
              class="mr-20px mt-40px text-22px !text-light-50"
            />
          </div>
          <div class="flex items-center mx-30px mt-40px">
            <SearchOutlined class="text-24px !text-light-50" />
            <Input
              allowClear
              ref={searchInputRef}
              bordered={false}
              placeholder="请输入关键字"
              class={inputStyles}
              onPressEnter={(e: any) => {
                searchInputRef.value.blur();
                router.push({
                  path: "/search",
                  query: { q: e.target.value },
                });
                state.showSearchOverlay = false;
              }}
            />
          </div>
        </div>
      </>
    );
  },
});

const inputStyles = css`
  .anticon.ant-input-clear-icon,
  .anticon.ant-input-clear-icon:hover,
  input {
    color: #fff;
    font-size: 18px;
  }
`;
