import { CloseOutlined, SearchOutlined } from "@ant-design/icons-vue";
import { css, cx } from "@linaria/core";
import { Input } from "ant-design-vue";
import { defineComponent, reactive, ref } from "vue";
import { useRouter } from "vue-router";

export default defineComponent({
  setup() {
    const router = useRouter();

    const searchInputRef = ref();

    const state = reactive({
      showSearch: false,
    });

    return () => (
      <>
        <div class="w-1/20 text-right text-gray-500">
          <SearchOutlined
            class="text-20px hover:text-primary"
            onClick={() => {
              state.showSearch = true;
              searchInputRef.value?.focus();
            }}
          />
        </div>
        <div
          class={cx(
            state.showSearch ? "w-90/100 opacity-100" : "w-0 opacity-0",
            "absolute h-1/1 flex items-center bg-light-50 overflow-hidden transition-all duration-500"
          )}
        >
          <div class="flex-1 flex items-center border-primary border-1 border-solid pl-10px py-5px">
            <SearchOutlined class="text-18px !text-gray-600" />
            <Input
              allowClear
              bordered={false}
              placeholder="请输入关键词"
              class="w-1/1"
              onPressEnter={(e: any) => {
                router.push({
                  path: "/search",
                  query: { q: e.target.value },
                });
                state.showSearch = false;
              }}
            />
          </div>
          <CloseOutlined
            onClick={() => (state.showSearch = false)}
            class="ml-20px text-20px cursor-pointer !text-gray-600 hover:opacity-60 transition-all"
          />
        </div>
      </>
    );
  },
});
