import { defineComponent, reactive } from "vue";
import { array, bool, object, string } from "vue-types";

import { css } from "@linaria/core";
import { List } from "ant-design-vue";
import { useRoute, useRouter } from "vue-router";

export default defineComponent({
  props: {
    dataSource: array<any>().isRequired,
    loading: bool(),
    actions: object() as any,
    gridType: string().def("article"),
  },
  setup(props, { slots }) {
    const state = reactive({
      loading: false,
    });
    const route = useRoute();
    const router = useRouter();

    return () => {
      const { dataSource, actions, gridType } = props;
      const grid =
        gridType == "article"
          ? { gutter: 18, column: 4, xs: 1, sm: 2, md: 2, lg: 3 }
          : { column: 1, gutter: 0 };
      return (
        <div class={ListContent}>
          <List
            loading={state.loading}
            grid={grid}
            dataSource={dataSource}
            rowKey={(item) => item._id}
            renderItem={({ item, index }) => {
              return <List.Item>{slots.item?.(item, index)}</List.Item>;
            }}
            pagination={{
              responsive: true,
              showSizeChanger: false,
              hideOnSinglePage: true,
              current: actions.state.page * 1,
              pageSize: actions.state.size,
              total: actions.state.total,
              onChange: (v) => {
                const query = { ...route.query, page: v };
                router.push({ path: route.path, query });
              },
            }}
          ></List>
        </div>
      );
    };
  },
});
const ListContent = css`
  .ant-pagination {
    text-align: center;

    .ant-pagination-item {
      &:hover {
        border-color: var(--vt-c-primary);
        color: var(--vt-c-primary);
        a {
          color: var(--vt-c-primary);
        }
      }
      &.ant-pagination-item-active {
        background: var(--vt-c-primary);
        border-color: var(--vt-c-primary);
        a {
          color: #fff;
        }
      }
    }
    &.mini {
      .ant-pagination-item {
        &:hover {
          border-color: transparent;
        }
      }
      .ant-pagination-prev,
      .ant-pagination-next {
        .ant-pagination-item-link {
          border-color: transparent;
        }
        &:hover {
          .ant-pagination-item-link {
            border-color: transparent;
          }
        }
      }
    }
    .ant-pagination-prev,
    .ant-pagination-next {
      &:hover {
        .ant-pagination-item-link {
          border-color: var(--vt-c-primary);
          color: var(--vt-c-primary);
        }
      }
    }
  }
`;
