import { isImage } from "@/utils";
import { css, cx } from "@linaria/core";
import { Button } from "ant-design-vue";
import dayjs from "dayjs";
import { defineComponent } from "vue";
import { any } from "vue-types";

export default defineComponent({
  props: {
    record: any(),
  },
  setup(props) {
    const getLink = (record: any) => {
      switch (record.type) {
        case "detail":
          return `/detail/${record.cid}`;
        case "list":
        case "article":
        default:
          return `/article/${record.cid}?aid=${record._id}`;
      }
    };

    return () => {
      const { record } = props;

      const isImg = isImage(record.summary || "");

      return (
        <div
          class={cx(
            itemStyles,
            "flex items-center py-20px px-25px overflow-hidden <md:(py-15px px-20px)"
          )}
        >
          <div class="mr-20px text-16px text-gray-500 <md:(mr-10px text-12px)">
            {dayjs(record.createTime).format("YYYY.MM.DD")}
          </div>
          <div class="flex-1 truncate text-16px <md:(text-14px) ">
            {record.type == "download" ? (
              record.title
            ) : (
              <router-link
                target="_blank"
                class="text-gray-800 hover:(text-primary underline)"
                to={getLink(record)}
              >
                {record.title}
              </router-link>
            )}
          </div>
          {record.type == "download" && (
            <>
              {isImg ? (
                <a href={record.summary} target="_blank" class="ml-20px">
                  <Button type="primary" size="small" ghost>
                    下载
                  </Button>
                </a>
              ) : (
                <a href={record.summary} class="ml-20px">
                  <Button type="primary" size="small" ghost>
                    下载
                  </Button>
                </a>
              )}
            </>
          )}
        </div>
      );
    };
  },
});

const itemStyles = css`
  border-bottom: 1px solid #f5f5f5;
`;
